#
# spec file for package ghc-JuicyPixels
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name JuicyPixels
%global pkgver %{pkg_name}-%{version}
Name:           ghc-%{pkg_name}
Version:        3.3.9
Release:        1.12
Summary:        Picture loading/serialization (in png, jpeg, bitmap, gif, tga, tiff and radiance)
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-binary-devel
BuildRequires:  ghc-binary-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-deepseq-prof
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-mtl-prof
BuildRequires:  ghc-primitive-devel
BuildRequires:  ghc-primitive-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-transformers-prof
BuildRequires:  ghc-vector-devel
BuildRequires:  ghc-vector-prof
BuildRequires:  ghc-zlib-devel
BuildRequires:  ghc-zlib-prof
ExcludeArch:    %{ix86}

%description
This library can load and store images in PNG,Bitmap, Jpeg, Radiance, Tiff and
Gif images.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc README.md changelog docimages

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Thu Jun  6 2024 Peter Simons <psimons@suse.com>
- Update JuicyPixels to version 3.3.9.
  v3.3.9 June 2024
  - ---------------
  * Something something compilation
* Tue Apr  9 2024 Peter Simons <psimons@suse.com>
- Update JuicyPixels to version 3.3.8 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Nov  7 2023 Peter Simons <psimons@suse.com>
- Update JuicyPixels to version 3.3.8 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Sun Jul 17 2022 Peter Simons <psimons@suse.com>
- Update JuicyPixels to version 3.3.8.
  v3.3.7 July 2022
  - ---------------
  * Dependence fidling
  * Jpg: do not call "error" in the parser, use fail instead.
* Wed Mar  9 2022 Peter Simons <psimons@suse.com>
- Update JuicyPixels to version 3.3.7.
  v3.3.7 March 2022
  - ----------------
  * Jpg: Fixing renderng bug with MCUs with single block in width and
    multiple in height
* Wed Oct 13 2021 psimons@suse.com
- Update JuicyPixels to version 3.3.6.
  v3.3.6 October 2021
  - ------------------
  * Bytestring bound bump
  * Fix bug #187.  (Some JPEGs are misidentified as SourceTiff.)
  * Fix EXIF handling of strings of four characters or fewer.
  * Fix endianness bug in short ExifString and ExifUndefined.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Wed May  6 2020 psimons@suse.com
- Update JuicyPixels to version 3.3.5.
  v3.3.5 January 2020
  - ------------------
  Maintenance release to push various pull requests onto
  hackage
  * Exporting Pixel32 (will)
  * Palettization of transparent frames in Gif (flutterlice)
  * Documentation fixes (lehins)
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Thu Oct  3 2019 psimons@suse.com
- Update JuicyPixels to version 3.3.4.
  v3.3.4 September 2019
  - --------------------
  * support reading compressed zTXt metadata from PNG files (claudeha)
  * Add helper functions to convert a DynamicImage to RGB16 (uglyoldbob)
  * Fix RGB to CMYK conversion (lehins)
* Thu Jun 20 2019 psimons@suse.com
- Update JuicyPixels to version 3.3.3.1.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/JuicyPixels-3.3.3.1/src/changelog
* Tue Jun 11 2019 Peter Simons <psimons@suse.com>
- Update Cabal file for more accurate build dependencies.
* Wed Dec 26 2018 Peter Simons <psimons@suse.com>
- Fix an incorrectly specified upper bound on the 'base' library.
* Mon Dec 17 2018 psimons@suse.com
- Update JuicyPixels to version 3.3.3.
  v3.3.3 December 2018
  - -------------------
  * Enhanced: loading of bitmap format (thanks to CLowcay)
  * Refactoring: exposing more internal modules (thanks to wyager)
  * Refactoring: exposing dynamicMap & dynamicPixelMap
    through `Codec.Picture` (thnks to LightAndLight)
* Thu Oct  4 2018 psimons@suse.com
- Update JuicyPixels to version 3.3.2.
  v3.3.2 October 2018
  - ------------------
  * Fix: GHC-8.6 compilation fix (no upper bound on base)
  * Fix: upper bound on containers (pull request phadej)
  * Fix: palette validation for gifs (pull request omedan)
  * New: More complete gif creation API (pull request omedan)
* Fri Aug 17 2018 psimons@suse.com
- Update JuicyPixels to version 3.3.1.
  v3.3.1 August 2018
  - -----------------
  * Fix: gif decoding of 1bit palette (fix Ornedan)
  * Fix: end of stream handling for gif's lzw encoding (fix Ornedan)
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Tue Jul 17 2018 psimons@suse.com
- Update JuicyPixels to version 3.3.
  v3.3 July 2018
  - -------------
  * New: Eq instances for image
  * Fix: color gif resolution offset
  * New: support for Float Tiff
  * Breaking change: New `ImageY32` constructor for `Dynamic`
    hence the version bump.
* Mon May 14 2018 psimons@suse.com
- Update JuicyPixels to version 3.2.9.5.
  * Fix: uniform color quantization
  * Compat for GHC-8.4 (pull request)
  * Fix: Progressive jpeg decoding when number of blocks of the MCU
    is below line size
  * Feature: Paletted alpha png saving
  * Fix: Adding correct import of Exif Flash for Jpeg (thanks to Alexander Kjeldaas)
  * Feature: Jpg Exif writing
  * Fix: Jpeg loading of extended sequential jpg, not sure of all
    the implications, works with the sample
* Mon Jun 19 2017 psimons@suse.com
- Update to version 3.2.8.2.
* Tue Mar 14 2017 psimons@suse.com
- Update to version 3.2.8.1 with cabal2obs.
* Sun Jan  8 2017 psimons@suse.com
- Update to version 3.2.8 revision 1 with cabal2obs.
* Thu Sep 15 2016 psimons@suse.com
- Update to version 3.2.8 revision 0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 3.2.7.2 revision 0 with cabal2obs.
* Thu Jun 30 2016 mimi.vx@gmail.com
- update to 3.2.7.2
  * Fix: no more libjpeg warning when decoding Juicy.Pixels encoded images.
* Sun Jun  5 2016 mimi.vx@gmail.com
- update to 3.2.7.1
  * Fix: some wrongly infinitely looping JPEG decoding
* Tue Jan 26 2016 mimi.vx@gmail.com
- update to 3.2.7
  * Addition: convertRGB8 and convertRGBA8 helper functions
  * Addition: new output colorspace for JPEG format: Y, RGB & CMYK
  * Addition: RGBA8 bitmap reading (thanks to mtolly)
  * Enhancement: Optimized JPG & Tiff reading (thanks to Calvin Beck)
  * Enhancement: INLINE SPECIALIZE for pixelMap (Pixel8 -> Pixel8) (thx to Calvin Beck)
  * Fix: GHC 8.0 compilation (thanks to phadej)
* Mon Dec  7 2015 mimi.vx@gmail.com
- update to 3.2.6.4
  * Fix: Fixing unwanted sharing with createMutableImage due to
    wrongly used INLINE pragma
* Wed Nov  4 2015 mimi.vx@gmail.com
- update to 3.2.6.2
  * Fix: Using minimal GIF version if outputing a single image.
* Mon Aug 31 2015 mimi.vx@gmail.com
- update to 3.2.6.1
  * Fix: handling of negative height & width in bitmap format
  * Fix: regression on Tiff parsing.
* Sun Aug 23 2015 mimi.vx@gmail.com
- update to 3.2.6
  * Added: imageToTga saving helper function.
  * Fix: don't invert TGA alpha channel.
  * Fix: various typo in documentation.
* Mon Jul 27 2015 mimi.vx@gmail.com
- update to 3.2.5.3
  * Fix: bumping vector upper bounds.
* Mon Jun  8 2015 mimi.vx@gmail.com
- update to 3.2.5.2
  * Adding: Width & Height metdata to help querying image information without
    decompressing the whole.
  * Adding: Source format metadata.
* Sun May 31 2015 mimi.vx@gmail.com
- update to 3.2.5.1
  * Fixing: utf-8 encoding of Jpg/Types causing problems with Haddock.
  * Adding: Metadata extraction for various file format.
  * Adding: Metadata writing for various file format.
  * Adding: light EXIF mapping.
  * Fix: handling of Tiff with predictors (thanks to Patrick Pelletier)
* Mon Apr 27 2015 mimi.vx@gmail.com
- update to 3.2.4
  * Adding: Traversals compatible with the lens library.
* Wed Apr 22 2015 mimi.vx@gmail.com
- update to 3.2.3.1
  * Fix: BMP output generated wrong size (thanks to mtolly).
  * Adding: Support for RGB in jpeg (yeah, that exist...)
  * Adding: Support of CMYK & YCrCbK color space in jpeg files.
  * Addinng: a pixelFoldMap functions analog to the `foldMap` function
  of the Foldable type class.
  * Fix: better performances for the pixelFold* functions
* Sun Feb  1 2015 mimi.vx@gmail.com
- initial commit of JuicyPixels lib
